@@ -138,7 +138,7 @@ def local_copy(remote):
             # File is remote, make local copy
             must_delete = True
             local = uid() + osp.splitext(remote)[1]
-            logger.info('Copying %s -> %s', remote, local)
+            logger.debug('Copying %s -> %s', remote, local)
             seutils.cp(remote, local)
             yield local
         else:
